package Log::ger::Manual;

our $DATE = '2017-06-30'; # DATE
our $VERSION = '0.011'; # VERSION

1;
# ABSTRACT: Manual for Log::ger

__END__

=pod

=encoding UTF-8

=head1 NAME

Log::ger::Manual - Manual for Log::ger

=head1 VERSION

version 0.011

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
